@@ -60,8 +60,8 @@ class ProjectLib():
     file_type: str, optional
         The file format of `file_name`
 
-    todo
-    -----
+    .. todo::
+
         NOTE: Currently support only one file
 
         To support many files, we can switch to using dict such as self._data_out[file_name]
@@ -149,12 +149,12 @@ class ProjectLib():
         file_type: str, optional
             The type of file, "json" or "csv"
 
-        Result
+        Returns
         ------
         dict
 
-        Example
-        -------
+        Examples
+        --------
 
         .. code-block:: python
 
@@ -192,6 +192,11 @@ class ParsedUrl(object):
         `cos://<cos-name>/<bucket>/<prefix>/`
     """
     def __init__(self):
+        """
+
+        Endpoints to change:
+        https://cloud.ibm.com/docs/cloud-object-storage?topic=cloud-object-storage-migrate-data-center
+        """
         self.endpoint_alias_mapping = {
             "us-geo": "s3-api.us-geo.objectstorage.softlayer.net",
             "us": "s3-api.us-geo.objectstorage.softlayer.net",
@@ -222,27 +227,57 @@ class ParsedUrl(object):
             "sao01": "s3.sao01.objectstorage.softlayer.net",
             "seo01": "s3.seo01.objectstorage.softlayer.net"
         }
+        # https://cloud.ibm.com/docs/cloud-object-storage?topic=cloud-object-storage-endpoints
+        self._dedicated_endpoints = [
+                "s3.us-south.cloud-object-storage.appdomain.cloud",
+                "s3.us-east.cloud-object-storage.appdomain.cloud",
+                "s3.eu-gb.cloud-object-storage.appdomain.cloud",
+                "s3.eu-de.cloud-object-storage.appdomain.cloud",
+                "s3.au-syd.cloud-object-storage.appdomain.cloud",
+                "s3.jp-tok.cloud-object-storage.appdomain.cloud",
+                # cross-region
+                "s3.us.cloud-object-storage.appdomain.cloud",
+                "s3.eu.cloud-object-storage.appdomain.cloud",
+                "s3.ap.cloud-object-storage.appdomain.cloud",
+                # single DC
+                "s3.ams03.cloud-object-storage.appdomain.cloud",
+                "s3.che01.cloud-object-storage.appdomain.cloud",
+                "s3.hkg02.cloud-object-storage.appdomain.cloud",
+                "s3.mex01.cloud-object-storage.appdomain.cloud",
+                "s3.mil01.cloud-object-storage.appdomain.cloud",
+                "s3.mon01.cloud-object-storage.appdomain.cloud",
+                "s3.osl01.cloud-object-storage.appdomain.cloud",
+                "s3.par01.cloud-object-storage.appdomain.cloud",
+                "s3.sjc04.cloud-object-storage.appdomain.cloud",
+                "s3.sao01.cloud-object-storage.appdomain.cloud",
+                "s3.seo01.cloud-object-storage.appdomain.cloud",
+                "s3.sng01.cloud-object-storage.appdomain.cloud",
+                "s3.tor01.cloud-object-storage.appdomain.cloud"
+                ]
         self.endpoint = None
         self.bucket = None
         self.prefix = None
 
     def get_exact_url(self, cos_url):
-        """convert COS URL from using alias to exact URL"""
+        """Convert COS URL from using alias to exact URL"""
         key = cos_url.split("/")[2]
         x = cos_url.replace(key, self.endpoint_alias_mapping.get(key, key), 1)
         return x
 
     def get_endpoint(self, cos_url):
+        """ Return the endpoint string from COS URL"""
         self.endpoint = cos_url.split("/")[2]
         self.endpoint = self.endpoint_alias_mapping.get(
             self.endpoint, self.endpoint)
         return self.endpoint
 
     def get_bucket(self, cos_url):
+        """ Return the bucket name from COS URL"""
         self.bucket = cos_url.split("/")[3]
         return self.bucket
 
     def get_prefix(self, cos_url):
+        """ Return the prefix part from COS URL"""
         self.prefix = cos_url[cos_url.replace('/', 'X', 3).find('/') + 1:]
         if len(self.prefix) > 0 and self.prefix[-1] == '*':
             self.prefix = self.prefix[:-1]
@@ -250,17 +285,48 @@ class ParsedUrl(object):
         return self.prefix
 
     def analyze_cos_url(self, cos_url):
-        """ return a namedtuple containing the 3 fields
+        """ Return a namedtuple containing the 3 fields
 
         * bucket
         * endpoint
         * prefix
+
+        Parameters
+        ----------
+        cos_url : str
+            COS URL
         """
         nt = namedtuple("COSURL", "endpoint bucket prefix")
         mycontainer = nt(self.get_endpoint(cos_url), self.get_bucket(cos_url),
                          self.get_prefix(cos_url))
         return mycontainer
 
+    def is_valid_cos_url(self, cos_url):
+        """ Validate if a string is COS URL
+
+        Returns
+        ------
+        bool
+        """
+        origin = str(cos_url)
+        cos_url = cos_url.strip()
+        if not cos_url.startswith("cos://"):
+            return False
+
+        cos_url = cos_url[6:]
+        if '/' not in cos_url:
+            return False
+        if cos_url[-1] != '/':
+            cos_url += '/'
+        if cos_url.count('/') < 2:
+            return False
+        endpoint = self.get_endpoint(origin)
+        if not endpoint in self.endpoint_alias_mapping.values() and \
+        not endpoint in self._dedicated_endpoints:
+            return False
+
+        return True
+
 
 # ---------------------------------------------------------------------------
 # Helper class to query information or manipulate data as objects on COS
@@ -268,6 +334,8 @@ class ParsedUrl(object):
 # ---------------------------------------------------------------------------
 class COSClient(ParsedUrl, IBMCloudAccess):
     """
+    This class handles the interaction with IBM COS storage
+
     Parameters
     ----------
     cloud_apikey : str, optional
@@ -295,6 +363,10 @@ class COSClient(ParsedUrl, IBMCloudAccess):
                                 cloud_apikey=cloud_apikey,
                                 client_info=client_info)
 
+        if cos_url is not None and len(cos_url) > 0:
+            if not self.is_valid_cos_url(cos_url):
+                msg = "Not a valid COS URL: {}".format(cos_url)
+                raise ValueError(msg)
         self.cos_url = cos_url
         # a dict holding all retrieved bucket's information
         self.buckets_info = {}
@@ -336,7 +408,7 @@ class COSClient(ParsedUrl, IBMCloudAccess):
         pd.DataFrame
             The following columns ("Object", "Size", "StorageClass")
 
-        Note
+        Notes
         ------
         Having a trailing slash (/) makes a difference in the returned result, as an asterisk is added at the end. So,
         "/prefix" would consider things like "/prefix_unexpected/value" and "/prefix/expected_value"; while
@@ -347,7 +419,15 @@ class COSClient(ParsedUrl, IBMCloudAccess):
             Only "list_objects' work for IBM COS, not 'list_objects_v2'
 
             `IBM-COS-SDK <https://ibm.github.io/ibm-cos-sdk-python/reference/services/s3.html#S3.Client.list_objects_v2>`_
+
+        Raises
+        -------
+        ValueError
+            if COS URL is invalid
         """
+        if not self.is_valid_cos_url(cos_url):
+            msg = "Not a valid COS URL: {}".format(cos_url)
+            raise ValueError(msg)
         self.logon()
 
         cos_url = self.get_exact_url(cos_url)
@@ -378,7 +458,15 @@ class COSClient(ParsedUrl, IBMCloudAccess):
     def delete_empty_objects(self, cos_url):
         """
         Delete zero-size objects. Reference to :meth:`.list_cos_objects` for further details.
+
+        Raises
+        -------
+        ValueError
+            if COS URL is invalid
         """
+        if not self.is_valid_cos_url(cos_url):
+            msg = "Not a valid COS URL: {}".format(cos_url)
+            raise ValueError(msg)
         result_objects = self.list_cos_objects(cos_url)
         url_parsed = self.analyze_cos_url(cos_url)
         cos_client = self._get_default_cos_client(url_parsed.endpoint)
@@ -390,11 +478,11 @@ class COSClient(ParsedUrl, IBMCloudAccess):
                                          Key=result_objects.Object[row])
 
     def delete_objects(self, cos_url, dry_run=False):
-        """delete all objects stored at the given COS URL
+        """Delete all objects stored at the given COS URL
 
         https://<cos-url>/<bucket>?prefix=<prefix-path>
 
-        Note
+        Notes
         ------
 
         Reference: `AWS doc <https://awsdocs.s3.amazonaws.com/S3/latest/s3-qrc.pdf>`_
@@ -432,7 +520,15 @@ class COSClient(ParsedUrl, IBMCloudAccess):
 
         As the entity tag (ETag) is a hash of the object, we can use it to reliably check whether the object has changed - better
         than just file size and modification date. Sample code to handle `request.response <https://sdbrett.com/BrettsITBlog/2017/03/python-parsing-api-xml-response-data/>`_
+
+        Raises
+        -------
+        ValueError
+            if COS URL is invalid
         """
+        if not self.is_valid_cos_url(cos_url):
+            msg = "Not a valid COS URL: {}".format(cos_url)
+            raise ValueError(msg)
         self.logon()
 
         print("COS URL: {}\n".format(cos_url))
@@ -503,6 +599,9 @@ class COSClient(ParsedUrl, IBMCloudAccess):
         Arguments:
             cos_url {str} -- The COS URL
         """
+        if not self.is_valid_cos_url(cos_url):
+            msg = "Not a valid COS URL: {}".format(cos_url)
+            raise ValueError(msg)
         self.logon()
 
         cos_url = self.get_exact_url(cos_url)
@@ -530,7 +629,16 @@ class COSClient(ParsedUrl, IBMCloudAccess):
         return result
 
     def get_bucket_info(self, cos_url):
-        """
+        """ Return the information of the given bucket
+
+        Raises
+        -------
+        ValueError
+            if invalid COS URL
+
+        Examples
+        --------
+
         .. code-block:: console
 
             curl https://config.cloud-object-storage.cloud.ibm.com/v1/b/my-bucket \
@@ -551,10 +659,13 @@ class COSClient(ParsedUrl, IBMCloudAccess):
             "bytes_used": 28198745752445144
             }
 
-        todo
-        ----
+        .. todo::
+
             https://cloud.ibm.com/apidocs/cos/cos-configuration?code=python
         """
+        if not self.is_valid_cos_url(cos_url):
+            msg = "Not a valid COS URL: {}".format(cos_url)
+            raise ValueError(msg)
         from cos_config.resource_configuration_v1 import ResourceConfigurationV1
         bucket = self.get_bucket(cos_url)
 
@@ -586,12 +697,17 @@ class COSClient(ParsedUrl, IBMCloudAccess):
         #     break
         # time.sleep(2)
 
-    def update_bucket(self, cos_url):
+    def _update_bucket(self, cos_url):
         """
-        todo
-        ----
+        Update the bucket given by COS URL
+
+        .. todo::
+
            revise this
         """
+        if not self.is_valid_cos_url(cos_url):
+            msg = "Not a valid COS URL: {}".format(cos_url)
+            raise ValueError(msg)
         from cos_config.resource_configuration_v1 import ResourceConfigurationV1
 
         api_key = self.apikey
@@ -699,7 +815,7 @@ class COSClient(ParsedUrl, IBMCloudAccess):
             self.read_project_lib_data(file_name)
 
     def read_project_lib_data(self, file_name=None):
-        """read the content from the given file (via ProjectLib in IBM Watson Studio's COS bucket)
+        """Read the content from the given file (via ProjectLib in IBM Watson Studio's COS bucket)
 
         Parameters
         ----------
@@ -712,7 +828,7 @@ class COSClient(ParsedUrl, IBMCloudAccess):
             self._project.read(file_name)
 
     def write_project_lib_data(self, file_name=None):
-        """write the content to the given file (via ProjectLib in IBM Watson Studio's COS bucket)
+        """Write the content to the given file (via ProjectLib in IBM Watson Studio's COS bucket)
 
         Parameters
         ----------
